==> haskell-sha-1.6.4.4-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sha.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: SHA
version: 1.6.4.4
id: SHA-1.6.4.4-1zvOUgVKaQx7KvqAhOzZXy
key: SHA-1.6.4.4-1zvOUgVKaQx7KvqAhOzZXy
license: BSD3
maintainer: Adam Wick <awick@galois.com>,
            Raphael Javaux <raphaeljavaux@gmail.com>
stability: stable
synopsis: Implementations of the SHA suite of message digest functions
description:
    This library implements the SHA suite of message digest functions,
    according to NIST FIPS 180-2 (with the SHA-224 addendum), as well
    as the SHA-based HMAC routines. The functions have been tested
    against most of the NIST and RFC test vectors for the various
    functions. While some attention has been paid to performance,
    these do not presently reach the speed of well-tuned libraries,
    like OpenSSL.
category: Cryptography, Codec
author: Adam Wick <awick@galois.com>, Brian Lewis <brian@lorf.org>
exposed: True
indefinite: False
exposed-modules:
    Data.Digest.Pure.SHA
abi: 234670dfcf5a5935d11e5c3ae2cc03c0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/SHA-1.6.4.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/SHA-1.6.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/SHA-1.6.4.4
hs-libraries: HSSHA-1.6.4.4-1zvOUgVKaQx7KvqAhOzZXy
depends:
    array-0.5.2.0 base-4.10.1.0 binary-0.8.5.1 bytestring-0.10.8.2
abi-depends: array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             binary-0.8.5.1=efb65bc450356b9ea572733928ffb43f
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-sha/html/SHA.haddock
haddock-html: /usr/share/doc/haskell-sha/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sha-1.6.4.4-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sha.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: SHA
version: 1.6.4.4
id: SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73
key: SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73
license: BSD-3-Clause
maintainer: Adam Wick <awick@galois.com>,
            Raphael Javaux <raphaeljavaux@gmail.com>
author: Adam Wick <awick@galois.com>, Brian Lewis <brian@lorf.org>
stability: stable
synopsis: Implementations of the SHA suite of message digest functions
description:
    This library implements the SHA suite of message digest functions,
    according to NIST FIPS 180-2 (with the SHA-224 addendum), as well
    as the SHA-based HMAC routines. The functions have been tested
    against most of the NIST and RFC test vectors for the various
    functions. While some attention has been paid to performance,
    these do not presently reach the speed of well-tuned libraries,
    like OpenSSL.
category: Cryptography, Codec
abi: c45bfd512334de8946bc84a4c38a38e5
exposed: True
exposed-modules:
    Data.Digest.Pure.SHA
import-dirs: /usr/lib/ghc-8.4.2/site-local/SHA-1.6.4.4
library-dirs: /usr/lib/ghc-8.4.2/site-local/SHA-1.6.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/SHA-1.6.4.4
hs-libraries: HSSHA-1.6.4.4-J97i4k52krALB5u9VxmQ73
depends:
    array-0.5.2.0 base-4.11.1.0 binary-0.8.5.1 bytestring-0.10.8.2
abi-depends: array-0.5.2.0=59560c027ff6ea5b7e467a38c579b575
             base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             binary-0.8.5.1=253349ae905e3b03d89d37316bf920b7
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
haddock-interfaces: /usr/share/doc/haskell-sha/html/SHA.haddock
haddock-html: /usr/share/doc/haskell-sha/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
